ScrollAnimationWidget class

Inheritance

Constructors

ScrollAnimationWidget({Key? key, required Widget child, required Alignment alignment, required String index, Duration duration = const Duration(milliseconds: 500), Curve curve = Curves.easeInOut, double visibilityThreshold = 0.3, bool reverseOnExit = true, bool enableScale = false, bool enableRotation = false, bool loopAnimation = false, bool alternate = false, bool enableFade = true, bool enableSlide = true, Duration delay = Duration.zero, bool resetOnScroll = false, VoidCallback? onAnimationStart, VoidCallback? onAnimationEnd})
const

Properties

alignment Alignment
final
alternate bool
final
child Widget
final
curve Curve
final
delay Duration
final
duration Duration
final
enableFade bool
final
enableRotation bool
final
enableScale bool
final
enableSlide bool
final
hashCode int
The hash code for this object.
no setterinherited
index String
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loopAnimation bool
final
onAnimationEnd VoidCallback?
final
onAnimationStart VoidCallback?
final
resetOnScroll bool
final
reverseOnExit bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibilityThreshold double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() ScrollAnimationWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited